Contact
======================================

To report a bug, discuss a feature you'd like to see
added, or if you have an idea or change you're interested
in contributing, visit the project `github
page <https://github.com/jlparkI/AntPack>`_. Bugs should
be reported under Issues, whereas questions, ideas
for useful changes, and proposed contributions should
go under Discussions.
